==> bitcream-smartsignage-custom-v0.4-263a7a.zip: backend/controllers/PresetController.php <==
<?php

namespace bitcream\smartsignage\custom\backend\controllers;

use Yii;
use bitcream\smartsignage\custom\backend\models\Preset;
use bitcream\smartsignage\custom\backend\models\PresetSearch;
use bitcream\smartsignage\custom\backend\models\Layout;
use bitcream\smartsignage\custom\backend\models\LayoutZone;
use bitcream\smartsignage\custom\backend\models\PresetContent;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use bitcream\smartsignage\custom\common\utils\Gotify;

/**
 * PresetController implements the CRUD actions for Preset model.
 */
class PresetController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Preset models.
     * @return mixed
     */
    public function actionIndex()
    {
        $model = new Preset();
        $searchModel = new PresetSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        $layouts = Layout::find()->all();

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'layouts' => $layouts,
            'model' => $model,
        ]);
    }

    /**
     * Displays a single Preset model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Preset model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Preset();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            $model->name = "Preset title - ".$model->id;
            $model->save(false);
            return $this->redirect(['update', 'id' => $model->id]);
        }
        
    }

    /**
     * Updates an existing Preset model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $arrPresetContent = array();
        $model = $this->findModel($id);
        $modelPresetContent = new PresetContent();

        $layoutZones = $model->layout->layoutZones;
        
        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['update', 'id' => $model->id]);
        }

        return $this->render('update', [
            'model' => $model,
            'layoutZones' => $layoutZones,
            'modelPresetContent' => $modelPresetContent
        ]);
    }

    /**
     * Deletes an existing Preset model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }


    /**
     * Creates a new Preset-content
     * @return mixed
     */
    public function actionCreateContent()
    {
        $model = new PresetContent();
        $request = Yii::$app->request->post();
        
        if ($model->load(Yii::$app->request->post())) {           

            $contentType = $request['PresetContent']['class']::getContentType();
            $contentModel = new $request['PresetContent']['class']();
            $contentModel->save(false);

            $model->class = $request['PresetContent']['class'];
            $model->zone_id = $request['zone'];
            $model->preset_id = $request['preset'];
            $model->object_id = $contentModel->id;
            $model->save();

            return $this->redirect([$contentType.'/update?id='.$contentModel->id."&preset=".$model->id]);
        }
    }

    /**
     * Finds the Preset model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Preset the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Preset::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('smartsignage', 'The requested page does not exist.'));
    }

    /**
     * Creates a new Preset-content
     * @return mixed
     */
    public function actionSendNotification()
    {
        Gotify::sendNotification("1", "titolo di prova", "testo di prova");
    }
}

==> bitcream-smartsignage-custom-v0.6-16ba45.zip: backend/controllers/PresetController.php <==
<?php

namespace bitcream\smartsignage\custom\backend\controllers;

use Yii;
use bitcream\smartsignage\custom\backend\models\Preset;
use bitcream\smartsignage\custom\backend\models\PresetSearch;
use bitcream\smartsignage\custom\backend\models\Layout;
use bitcream\smartsignage\custom\backend\models\LayoutZone;
use bitcream\smartsignage\custom\backend\models\PresetContent;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use bitcream\smartsignage\custom\common\utils\Gotify;

/**
 * PresetController implements the CRUD actions for Preset model.
 */
class PresetController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Preset models.
     * @return mixed
     */
    public function actionIndex()
    {
        $model = new Preset();
        $searchModel = new PresetSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        $layouts = Layout::find()->all();

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'layouts' => $layouts,
            'model' => $model,
        ]);
    }

    /**
     * Displays a single Preset model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Preset model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Preset();

        $layouts = Layout::find()->all();

        if (Yii::$app->request->post() && $model->save()) {
            $model->layout_id = Yii::$app->request->post()["layout"];
            $model->name = "Preset title - ".$model->id;
            $model->save(false);
            return $this->redirect(['update', 'id' => $model->id]);
        }
        return $this->render('create', [
            'model' => $model,
            'layouts' => $layouts,
        ]);

    }

    /**
     * Updates an existing Preset model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $arrPresetContent = array();
        $model = $this->findModel($id);
        $modelPresetContent = new PresetContent();

        $layoutZones = $model->layout->layoutZones;

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['update', 'id' => $model->id]);
        }

        return $this->render('update', [
            'model' => $model,
            'layoutZones' => $layoutZones,
            'modelPresetContent' => $modelPresetContent
        ]);
    }

    /**
     * Deletes an existing Preset model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }


    /**
     * Creates a new Preset-content
     * @return mixed
     */
    public function actionCreateContent()
    {
        $model = new PresetContent();
        $request = Yii::$app->request->post();
        
        if ($model->load(Yii::$app->request->post())) {           

            $presetContentOnZone = $model->checkPresetContentOnZone($request['zone']);
            
            if($presetContentOnZone == false){
                $contentType = $request['PresetContent']['class']::getContentType();
                $contentModel = new $request['PresetContent']['class']();
                $contentModel->save(false);
    
                $model->class = $request['PresetContent']['class'];
                $model->zone_id = $request['zone'];
                $model->preset_id = $request['preset'];
                $model->object_id = $contentModel->id;
                $model->save();

                return $this->redirect([$contentType.'/update?id='.$contentModel->id."&preset=".$model->id]);
            }else{
                $contentType = $presetContentOnZone->class::getContentType();
                return $this->redirect([$contentType.'/update?id='.$presetContentOnZone->content->id."&preset=".$presetContentOnZone->id]);
            }            
        }
    }

    /**
     * Finds the Preset model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Preset the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Preset::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('smartsignage', 'The requested page does not exist.'));
    }
}
